# coding=utf-8
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstField import KeuzelijstField
from otlmow_model.OtlmowModel.BaseClasses.KeuzelijstWaarde import KeuzelijstWaarde


# Generated with OTLEnumerationCreator. To modify: extend, do not edit
class KlNetwerkkaartModelnaam(KeuzelijstField):
    """Modelnamen voor Netwerkkaarten."""
    naam = 'KlNetwerkkaartModelnaam'
    label = 'Netwerkkaart modelnaam'
    objectUri = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#KlNetwerkkaartModelnaam'
    definition = 'Modelnamen voor Netwerkkaarten.'
    status = 'ingebruik'
    codelist = 'https://wegenenverkeer.data.vlaanderen.be/id/conceptscheme/KlNetwerkkaartModelnaam'
    options = {
        'ASC105': KeuzelijstWaarde(invulwaarde='ASC105',
                                   label='ASC105',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ASC105'),
        'ASC108': KeuzelijstWaarde(invulwaarde='ASC108',
                                   label='ASC108',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ASC108'),
        'ASC109': KeuzelijstWaarde(invulwaarde='ASC109',
                                   label='ASC109',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ASC109'),
        'ASC110': KeuzelijstWaarde(invulwaarde='ASC110',
                                   label='ASC110',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ASC110'),
        'CL-DUAL-FC8': KeuzelijstWaarde(invulwaarde='CL-DUAL-FC8',
                                        label='CL-DUAL-FC8',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CL-DUAL-FC8'),
        'CMC410': KeuzelijstWaarde(invulwaarde='CMC410',
                                   label='CMC410',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CMC410'),
        'CMC418': KeuzelijstWaarde(invulwaarde='CMC418',
                                   label='CMC418',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CMC418'),
        'CN-100-C4L': KeuzelijstWaarde(invulwaarde='CN-100-C4L',
                                       label='CN-100-C4L',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-100-C4L'),
        'CN-100-C80': KeuzelijstWaarde(invulwaarde='CN-100-C80',
                                       label='CN-100-C80',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-100-C80'),
        'CN-200-B80': KeuzelijstWaarde(invulwaarde='CN-200-B80',
                                       label='CN-200-B80',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-200-B80'),
        'CN-200-R80': KeuzelijstWaarde(invulwaarde='CN-200-R80',
                                       label='CN-200-R80',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-200-R80'),
        'CN-200-RBS': KeuzelijstWaarde(invulwaarde='CN-200-RBS',
                                       label='CN-200-RBS',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-200-RBS'),
        'CN-C4L-00': KeuzelijstWaarde(invulwaarde='CN-C4L-00',
                                      label='CN-C4L-00',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-C4L-00'),
        'CN-C80-13': KeuzelijstWaarde(invulwaarde='CN-C80-13',
                                      label='CN-C80-13',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-C80-13'),
        'CN-OPS-2': KeuzelijstWaarde(invulwaarde='CN-OPS-2',
                                     label='CN-OPS-2',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/CN-OPS-2'),
        'F10-A90-33': KeuzelijstWaarde(invulwaarde='F10-A90-33',
                                       label='F10-A90-33',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/F10-A90-33'),
        'F10-A90-34': KeuzelijstWaarde(invulwaarde='F10-A90-34',
                                       label='F10-A90-34',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/F10-A90-34'),
        'F10-A90-35': KeuzelijstWaarde(invulwaarde='F10-A90-35',
                                       label='F10-A90-35',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/F10-A90-35'),
        'F10-T90-T31': KeuzelijstWaarde(invulwaarde='F10-T90-T31',
                                        label='F10-T90-T31',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/F10-T90-T31'),
        'F10E-A90-TN': KeuzelijstWaarde(invulwaarde='F10E-A90-TN',
                                        label='F10E-A90-TN',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/F10E-A90-TN'),
        'F10E-T90-TN': KeuzelijstWaarde(invulwaarde='F10E-T90-TN',
                                        label='F10E-T90-TN',
                                        status='ingebruik',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/F10E-T90-TN'),
        'FC4-T90-TN': KeuzelijstWaarde(invulwaarde='FC4-T90-TN',
                                       label='FC4-T90-TN',
                                       status='ingebruik',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/FC4-T90-TN'),
        'LKA146': KeuzelijstWaarde(invulwaarde='LKA146',
                                   label='LKA146',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA146'),
        'LKA39': KeuzelijstWaarde(invulwaarde='LKA39',
                                  label='LKA39',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA39'),
        'LKA412': KeuzelijstWaarde(invulwaarde='LKA412',
                                   label='LKA412',
                                   status='ingebruik',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA412'),
        'LKA48': KeuzelijstWaarde(invulwaarde='LKA48',
                                  label='LKA48',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA48'),
        'LKA53': KeuzelijstWaarde(invulwaarde='LKA53',
                                  label='LKA53',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA53'),
        'LKA58': KeuzelijstWaarde(invulwaarde='LKA58',
                                  label='LKA58',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA58'),
        'LKA62': KeuzelijstWaarde(invulwaarde='LKA62',
                                  label='LKA62',
                                  status='ingebruik',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/LKA62'),
        'M6': KeuzelijstWaarde(invulwaarde='M6',
                               label='M6',
                               status='ingebruik',
                               objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/M6'),
        'NTK505DA': KeuzelijstWaarde(invulwaarde='NTK505DA',
                                     label='NTK505DA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK505DA'),
        'NTK505FB': KeuzelijstWaarde(invulwaarde='NTK505FB',
                                     label='NTK505FB',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK505FB'),
        'NTK505QA': KeuzelijstWaarde(invulwaarde='NTK505QA',
                                     label='NTK505QA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK505QA'),
        'NTK505RA': KeuzelijstWaarde(invulwaarde='NTK505RA',
                                     label='NTK505RA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK505RA'),
        'NTK505SB': KeuzelijstWaarde(invulwaarde='NTK505SB',
                                     label='NTK505SB',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK505SB'),
        'NTK505YA': KeuzelijstWaarde(invulwaarde='NTK505YA',
                                     label='NTK505YA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK505YA'),
        'NTK507LD': KeuzelijstWaarde(invulwaarde='NTK507LD',
                                     label='NTK507LD',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK507LD'),
        'NTK507MD': KeuzelijstWaarde(invulwaarde='NTK507MD',
                                     label='NTK507MD',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK507MD'),
        'NTK507NA': KeuzelijstWaarde(invulwaarde='NTK507NA',
                                     label='NTK507NA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK507NA'),
        'NTK507PB': KeuzelijstWaarde(invulwaarde='NTK507PB',
                                     label='NTK507PB',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK507PB'),
        'NTK529AC': KeuzelijstWaarde(invulwaarde='NTK529AC',
                                     label='NTK529AC',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK529AC'),
        'NTK529BA': KeuzelijstWaarde(invulwaarde='NTK529BA',
                                     label='NTK529BA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK529BA'),
        'NTK530PM': KeuzelijstWaarde(invulwaarde='NTK530PM',
                                     label='NTK530PM',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK530PM'),
        'NTK530QA': KeuzelijstWaarde(invulwaarde='NTK530QA',
                                     label='NTK530QA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK530QA'),
        'NTK532DA': KeuzelijstWaarde(invulwaarde='NTK532DA',
                                     label='NTK532DA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK532DA'),
        'NTK536BE': KeuzelijstWaarde(invulwaarde='NTK536BE',
                                     label='NTK536BE',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK536BE'),
        'NTK536FB': KeuzelijstWaarde(invulwaarde='NTK536FB',
                                     label='NTK536FB',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK536FB'),
        'NTK538BM': KeuzelijstWaarde(invulwaarde='NTK538BM',
                                     label='NTK538BM',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK538BM'),
        'NTK539UD': KeuzelijstWaarde(invulwaarde='NTK539UD',
                                     label='NTK539UD',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK539UD'),
        'NTK552AB': KeuzelijstWaarde(invulwaarde='NTK552AB',
                                     label='NTK552AB',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK552AB'),
        'NTK555CA': KeuzelijstWaarde(invulwaarde='NTK555CA',
                                     label='NTK555CA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK555CA'),
        'NTK555NA': KeuzelijstWaarde(invulwaarde='NTK555NA',
                                     label='NTK555NA',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK555NA'),
        'NTK555NB': KeuzelijstWaarde(invulwaarde='NTK555NB',
                                     label='NTK555NB',
                                     status='ingebruik',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NTK555NB'),
        'NULL': KeuzelijstWaarde(invulwaarde='NULL',
                                 label='NULL',
                                 status='ingebruik',
                                 objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/NULL'),
        'Other': KeuzelijstWaarde(invulwaarde='Other',
                                  label='Other',
                                  status='ingebruik',
                                  definitie='Deze optie mag uitsluitend TIJDELIJK worden gebruikt en enkel tot de juiste gegevens beschikbaar zijn. Misbruik van deze optie leidt tot verminderde datakwaliteit.',
                                  objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/Other'),
        'PSM-12V': KeuzelijstWaarde(invulwaarde='PSM-12V',
                                    label='PSM-12V',
                                    status='ingebruik',
                                    objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/PSM-12V'),
        'RS-10G-4P': KeuzelijstWaarde(invulwaarde='RS-10G-4P',
                                      label='RS-10G-4P',
                                      status='ingebruik',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/RS-10G-4P'),
        'cn-100-a80': KeuzelijstWaarde(invulwaarde='cn-100-a80',
                                       label='CN-100-A80',
                                       status='ingebruik',
                                       definitie='CN-100-A80',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/cn-100-a80'),
        'dcdm-8he': KeuzelijstWaarde(invulwaarde='dcdm-8he',
                                     label='DCDM-8HE',
                                     status='uitgebruik',
                                     definitie='DCDM-8HE',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/dcdm-8he'),
        'dcmd-8he': KeuzelijstWaarde(invulwaarde='dcmd-8he',
                                     label='DCMD-8HE',
                                     status='ingebruik',
                                     definitie='DCMD-8HE',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/dcmd-8he'),
        'ddad-1-34': KeuzelijstWaarde(invulwaarde='ddad-1-34',
                                      label='DDAD-1-34',
                                      status='ingebruik',
                                      definitie='DDAD-1-34',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ddad-1-34'),
        'ddad-2': KeuzelijstWaarde(invulwaarde='ddad-2',
                                   label='DDAD-2',
                                   status='ingebruik',
                                   definitie='DDAD-2',
                                   objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ddad-2'),
        'ddad-2-3536': KeuzelijstWaarde(invulwaarde='ddad-2-3536',
                                        label='DDAD-2-3536',
                                        status='ingebruik',
                                        definitie='DDAD-2-3536',
                                        objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ddad-2-3536'),
        'ddlt-1-39': KeuzelijstWaarde(invulwaarde='ddlt-1-39',
                                      label='DDLT-1-39',
                                      status='ingebruik',
                                      definitie='DDLT-1-39',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ddlt-1-39'),
        'ddm-8-3441': KeuzelijstWaarde(invulwaarde='ddm-8-3441',
                                       label='DDM-8-3441',
                                       status='ingebruik',
                                       definitie='DDM-8-3441',
                                       objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ddm-8-3441'),
        'n-100-a80': KeuzelijstWaarde(invulwaarde='n-100-a80',
                                      label='N-100-A80',
                                      status='uitgebruik',
                                      definitie='N-100-A80',
                                      objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/n-100-a80'),
        'ntk615ba': KeuzelijstWaarde(invulwaarde='ntk615ba',
                                     label='NTK615BA',
                                     status='ingebruik',
                                     definitie='NTK615BA',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ntk615ba'),
        'ntk667ab': KeuzelijstWaarde(invulwaarde='ntk667ab',
                                     label='NTK667AB',
                                     status='ingebruik',
                                     definitie='NTK667AB',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ntk667ab'),
        'ntk669am': KeuzelijstWaarde(invulwaarde='ntk669am',
                                     label='NTK669AM',
                                     status='ingebruik',
                                     definitie='NTK669AM',
                                     objectUri='https://wegenenverkeer.data.vlaanderen.be/id/concept/KlNetwerkkaartModelnaam/ntk669am')
    }

    @classmethod
    def create_dummy_data(cls):
        return cls.create_dummy_data_keuzelijst(cls.options)

