# coding=utf-8
from ...Classes.Onderdeel.SoortenrijkSchraalGraslandGraslandfase5 import SoortenrijkSchraalGraslandGraslandfase5


# Generated with OTLClassCreator. To modify: extend, do not edit
class Duingrasland(SoortenrijkSchraalGraslandGraslandfase5):
    """G5a - Zanddoddengras, Kleverige reigersbek, Ruw vergeet-mij-nietje, Kruipend stalkruid, Zandhoornbloem, Duinfakkelgras, Liggende asperge, Duindravik, Duinviooltje, Kegelsilene, Ruwe klaver, Duin- en gewimperd langbaardgras, Lathyruswikke, Geel walstro, Grote tijm, Geel zonneroosje, Liggend bergvlas, Nachtsilene, Walstrobremraap, Kalkbedstro, Zachte haver, Voorjaarsganzerik, Duindravik, Gestreepte klaver, Wondklaver."""

    typeURI = 'https://wegenenverkeer.data.vlaanderen.be/ns/onderdeel#Duingrasland'
    """De URI van het object volgens https://www.w3.org/2001/XMLSchema#anyURI."""

    def __init__(self):
        super().__init__()
